@@ -118,7 +118,6 @@ class Batch(Workflow, ModelSQL, ModelView):
     def on_change_journal(self):
         BatchLine = Pool().get('account.batch.line')
         if self.journal:
-            print('a', self.journal.account)
             self.journal_type = self.journal.account_journal.type
             account_journal = self.journal.account_journal
             # For correct start balance check of bank batches there may be no
@@ -421,7 +420,8 @@ class BatchLine(ModelSQL, ModelView):
                 values['journal'] = context.get('journal')
 
             if 'account' in fields:
-                values['account'] = journal.account.id
+                if journal.account:
+                    values['account'] = journal.account.id
 
             if 'side_account' in fields:
                 values['side_account'] = side
